@@ -172,7 +172,14 @@ def {link.name}(self, _: T.Optional[{link_resolver_name}] = None, /, ignore_if_s
     return self
 
 def {link.name}__count(self, _: T.Optional[{link_resolver_name}] = None, /, ignore_if_subset: bool = False, make_first: bool = False) -> {node_resolver_name}:
-    self._nested_resolvers.add("{link.name}__count", _ or {link_resolver_name}(), ignore_if_subset=ignore_if_subset, make_first=make_first)
+    rez = _ or {link_resolver_name}()
+    rez.is_count = True
+    self._nested_resolvers.add(
+        "{link.name}__count",
+        rez,
+        ignore_if_subset=ignore_if_subset,
+        make_first=make_first
+    )
     return self
     """
 
